function y_mx_c_fit_from_excel
fsize = 18;  %Fontsize for graphs

%Read Excel data
[filename, pathname] = uigetfile({'*.xls';'*xlsx'});
if isempty(pathname); return; end
[num,txt,raw] = xlsread( [pathname,filename] );
x = num(:,1).'; y = num(:,2).';

%Determine line of best fit
[yfit,xfit,r,m,c,dm,dc,yupper,ylower,s] = bestfitc(x,y);

%Plot line of best fit, overlaid with data
figure('name','line of best fit','color',[1 1 1]);
plot( xfit, yfit, 'k-', xfit, yupper, 'b--', xfit, ylower, 'g--' );
hold on; plot( x,y,'r+');
xlabel('x','fontsize',fsize); ylabel('y','fontsize',fsize);
set(gca,'fontsize',fsize); grid on;
if c >=0
    c_sign = '+';
else
    c_sign = '-';
end
title( {['Line of best fit y = ',num2str(m,3),'x ',c_sign,' ',num2str(abs(c),3)],...
    ['\Deltam = ',num2str(dm,3),', \Deltac = ',num2str(dc,2),', r = ',num2str(r,3)] }, 'fontsize',fsize );
print( gcf, [filename,'.png'],'-dpng','-r300' );
close(gcf);

%%

%Line of best fit function yfit = m*x +c, with product moment correlation
%coefficient r
function [yfit,xfit,r,m,c,dm,dc,yupper,ylower,s] = bestfitc(x,y)

%Find any x or y values that are NaN or Inf
ignore = isnan(abs(x)) | isnan(abs(y)) | isinf(abs(x)) | isinf(abs(y));
x(ignore) = []; y(ignore) = [];
n = length(x);

%Compute line of best fit
xbar = mean(x); ybar = mean(y); xybar = mean(x.*y);
xxbar = mean(x.^2 ); yybar = mean(y.^2 );
Vx = xxbar - xbar^2; Vy = yybar - ybar^2;
COVxy = xybar - xbar*ybar;
m = COVxy/Vx; c = ybar - m*xbar; r = COVxy/sqrt( Vx*Vy );
[x,i] = sort(x); y = y(i);
yfit = m*x + c; xfit = x;

%Compute errors in gradient m and intercept c
s = sqrt( (1/(n-2))*sum( (y - yfit).^2 ) );
dm = s/sqrt(n*Vx);
dc = ( s/sqrt(n) )*sqrt( 1 + (xbar^2)/Vx );

%Determine envelope lines
yupper = (m+dm)*x + c - dc;
ylower = (m-dm)*x + c + dc;

%End of code